@@ -12,7 +12,6 @@ from __future__ import annotations
 
 __all__ = ['workflow_stddft']
 
-import logging
 from os.path import join
 from typing import Tuple, TYPE_CHECKING
 
@@ -24,6 +23,7 @@ from noodles.interface import PromisedObject
 from qmflows.parsers import parse_string_xyz
 from qmflows.type_hints import PathLike
 
+from .. import logger
 from ..common import (DictConfig, angs2au, change_mol_units, h2ev, hardness,
                       is_data_in_hdf5, number_spherical_functions_per_atom,
                       retrieve_hdf5_data, store_arrays_in_hdf5, xc)
@@ -35,9 +35,6 @@ if TYPE_CHECKING:
     from numpy.typing import NDArray
     from numpy import float64 as f8
 
-# Starting logger
-logger = logging.getLogger(__name__)
-
 
 def workflow_stddft(config: DictConfig) -> None:
     """Compute the excited states using simplified TDDFT.
@@ -499,7 +496,6 @@ def compute_MNOK_integrals(mol, xc_dft):
     n_atoms = len(mol)
     r_ab = get_r_ab(mol)
     hardness_vec = np.stack([hardness(m[0]) for m in mol]).reshape(n_atoms, 1)
-    print("hardness: ", [m[0].capitalize() for m in mol])
     hard = np.add(hardness_vec, hardness_vec.T)
     beta = xc(xc_dft)['beta1'] + xc(xc_dft)['ax'] * xc(xc_dft)['beta2']
     alpha = xc(xc_dft)['alpha1'] + xc(xc_dft)['ax'] * xc(xc_dft)['alpha2']
